@@ -215,8 +215,8 @@ void file_delete_edit(const gchar *file)
     tmaid,TXTウインドウ情報                                                 */
 void file_open_text(TmaidWindow *tmaid)
 {
-    gchar buf[16384], **charset, *ptr, *tmp, *inbuf = NULL, *outbuf = NULL;
-    gssize bytes_read_prev, bytes_read, bytes_written, leng, length = 0;
+    gchar buf[16384], **charset, *ptr, *inbuf = NULL, *outbuf = NULL;
+    gssize bytes_read, bytes_written, leng, length = 0;
     gint i, j, crlf[3];
     gunichar c;
     FileIO *fio;
@@ -273,6 +273,8 @@ void file_open_text(TmaidWindow *tmaid)
         if (error != NULL && g_error_matches (error, G_CONVERT_ERROR,
                                                 G_CONVERT_ERROR_NO_CONVERSION))
           {
+            gchar *tmp;
+
             /* キャラクターセットが無効 */
             tmp = g_strdup_printf (_("Conversion from character encoding"
                             " '%s' to 'UTF-8' is not supported"), charset[i]);
@@ -293,19 +295,23 @@ void file_open_text(TmaidWindow *tmaid)
     if (outbuf == NULL)
         for (i = 0; userbreak && outbuf == NULL && charset[i] != NULL; i++)
           {
-            bytes_read_prev = -1;
+            gchar *buffer;
+            gssize bytes_read_prev = -1;
+
+            buffer = g_memdup (inbuf, length);
             while ((g_clear_error (&error),
-                (outbuf = g_convert (inbuf, length, "UTF-8", charset[i],
+                (outbuf = g_convert (buffer, length, "UTF-8", charset[i],
                                 &bytes_read, &bytes_written, &error)) == NULL)
                             && bytes_read_prev != bytes_read && error != NULL
                             && g_error_matches (error, G_CONVERT_ERROR,
                                             G_CONVERT_ERROR_ILLEGAL_SEQUENCE))
               {
                 while (gtk_events_pending ())
-                    gtk_main_iteration ();
-                inbuf[bytes_read] = '?';
+                  gtk_main_iteration ();
+                buffer[bytes_read] = '?';
                 bytes_read_prev = bytes_read;
               }
+            g_free (buffer);
             g_clear_error (&error);
             if (outbuf != NULL)
                 break;
@@ -492,7 +498,7 @@ void file_open_text(TmaidWindow *tmaid)
      RET,TXTウインドウ情報                                                  */
 TmaidWindow *file_open_edit(const gchar *file)
 {
-    gchar *ext, *p, *text, **charset;
+    gchar *ext, *p, *text, **charset, *utf8str;
     gint i, x, y;
     TmaidWindow *tmaid;
     GdkRectangle rc;
@@ -644,6 +650,8 @@ TmaidWindow *file_open_edit(const gchar *file)
     g_object_set_data (G_OBJECT(table), "user_data", tmaid);
     /* メニュー */
     menu_shell = gtk_item_factory_get_widget (ifactory_menu, "<main>/Window");
+    utf8str = g_filename_to_utf8 (tmaid->file, -1, NULL, NULL, NULL);
+    g_free (utf8str);
     tmaid->menu_item=gtk_menu_item_new_with_label(tmaid->file);
     g_signal_connect (G_OBJECT (tmaid->menu_item), "activate",
                             G_CALLBACK (signal_activate_menu_window), table);
