@@ -20,7 +20,6 @@
 #include "tmaid.h"
 #include "charlist.h"
 #include "command.h"
-#include "conf.h"
 #include "file.h"
 #include "find.h"
 #include "format.h"
@@ -35,11 +34,9 @@
 #include "misc/argument.h"
 #include "misc/fileio.h"
 #include "misc/license.h"
+#include "misc/misc_accel.h"
+#include "misc/misc_comm.h"
 #include "misc/profile.h"
-#ifdef G_OS_WIN32
-# include <tchar.h>
-# include <windows.h>
-#endif /* G_OS_WIN32 */
 
 
 gboolean caret=FALSE;               /* キャレットの形 */
@@ -50,11 +47,9 @@ gchar *history_files[10];           /* ファイルの履歴 */
 gchar *open_path=NULL;              /* 開くのパス */
 gchar *save_path=NULL;              /* 名前を付けて保存のパス */
 gchar *clipboard_text=NULL;         /* クリップボードのテキスト */
-gchar *arg_text=NULL;               /* プロセス間通信用変数 */
 gint def_width,def_height;          /* デフォルトのウインドウのサイズ */
 gint ftnum=0;                       /* ファイルタイプの数 */
 gint history=4;                     /* ファイルの履歴 */
-gint instance=-1;                   /* プロセス間通信用変数 */
 gint tcount=0;                      /* ファイルタイプのカウンタ */
 guint timer_id=0;                   /* タイマID */
 FileType *ftype=NULL;               /* ファイルタイプ */
@@ -62,8 +57,6 @@ GdkAtom atom_targets;               /* ターゲット */
 GdkAtom atom_text;                  /* テキスト */
 GdkAtom atom_compound;              /* コンパウンド */
 GdkAtom atom_utf8;                  /* UTF-8 */
-GdkAtom atom_textmaid0;             /* プロセス間通信用アトム */
-GdkAtom atom_textmaid1;             /* プロセス間通信用アトム */
 GtkWidget *window;                  /* ウインドウ */
 GtkWidget *notebook;                /* ノートブック */
 GtkWidget *status;                  /* ステータスウインドウ */
@@ -90,137 +83,6 @@ GtkTargetEntry targets[4]={         /* Text maidが提供可能なセレクシ
 * メイン関数                                                                  *
 *                                                                             *
 ******************************************************************************/
-#ifdef G_OS_WIN32
-static DWORD ddeInst = 0;
-static HSZ hszService = NULL;
-static HSZ hszTopic0 = NULL, hszTopic1 = NULL, hszTopic2 = NULL;
-
-
-static HDDEDATA CALLBACK
-DdemlCallback (UINT uType, UINT uFmt, HCONV hConv, HSZ hszTopic, HSZ hszServ,
-                                HDDEDATA hData, DWORD dwData1, DWORD dwData2)
-{
-    switch (uType)
-      {
-        case XTYP_CONNECT:
-            if (DdeCmpStringHandles (hszServ, hszService) != 0)
-                return (HDDEDATA)FALSE;
-            if (DdeCmpStringHandles (hszTopic, hszTopic0) == 0)
-              {
-                hConv = DdeConnect (ddeInst, hszService, hszTopic1, NULL);
-                if (hConv != NULL)
-                    DdeClientTransaction (NULL, 0, hConv, hszTopic1,
-                                CF_TEXT, XTYP_REQUEST, TIMEOUT_ASYNC, NULL);
-                return (HDDEDATA)TRUE;
-              }
-            else if (DdeCmpStringHandles (hszTopic, hszTopic1) == 0)
-              {
-                return (HDDEDATA)TRUE;
-              }
-            else if (DdeCmpStringHandles (hszTopic, hszTopic2) == 0)
-              {
-                g_free (arg_text);
-                arg_text = NULL;
-                return (HDDEDATA)TRUE;
-              }
-            return (HDDEDATA)FALSE;
-        case XTYP_REQUEST:
-            if (DdeCmpStringHandles (hszTopic, hszTopic1) == 0)
-                return  DdeCreateDataHandle (ddeInst, arg_text,
-                            g_strlen (arg_text) + 1, 0, hszTopic1, CF_TEXT, 0);
-            break;
-        case XTYP_XACT_COMPLETE:
-            if (DdeCmpStringHandles (hszTopic, hszTopic1) == 0)
-              {
-                /* コマンドラインの解析 */
-                gchar *text;
-
-                DdeDisconnect (hConv);
-                text = DdeAccessData (hData, NULL);
-                if (text != NULL)
-                  {
-                    gboolean *arg_files;
-                    gchar **argv;
-                    TmaidWindow *tmaid;
-                    gint i, array[2], def[2];
-                    ArgumentBool arg_n, arg_x;
-                    ArgumentValue arg_h, arg_l;
-                    ArgumentArray arg_s;
-                    ArgumentList arg_opts[] = {
-{"history", 'h',  "NUM",          N_("History"),        ARGUMENT_TYPE_VALUE, &arg_h},
-{"line",    'l',  "NUM",          N_("Caret Position"), ARGUMENT_TYPE_VALUE, &arg_l},
-{"new",     'n',  "ON/OFF",       N_("New File"),       ARGUMENT_TYPE_BOOL,  &arg_n},
-{"size",    's',  "WIDTH,HEIGHT", N_("Window Size"),    ARGUMENT_TYPE_ARRAY, &arg_s},
-{"second",  'x',  "ON/OFF",       N_("Open Window"),    ARGUMENT_TYPE_BOOL,  &arg_x},
-{NULL,      '\0', NULL,           NULL,                 0,                   NULL}};
-
-                    /* ja:ファイルの履歴 */
-                    arg_h.val = history;
-                    arg_h.def = 4;
-                    /* ja:初期のキャレット位置 */
-                    arg_l.val = 0;
-                    arg_l.def = 0;
-                    /* ja:新規ファイル */
-                    arg_n.flag = newfile;
-                    arg_n.def = FALSE;
-                    /* ja:ウインドウサイズ */
-                    array[0] = def_width;
-                    array[1] = def_height;
-                    def[0] = gdk_screen_width ()  * 2 / 3;
-                    def[1] = gdk_screen_height () * 2 / 3;
-                    arg_s.leng = 2;
-                    arg_s.array = array;
-                    arg_s.def = def;
-                    /* ja:新規ウインドウ */
-                    arg_x.flag = second;
-                    arg_x.def = FALSE;
-                    /* ja:コマンドラインの解析 */
-                    argv = g_strsplit (text, "\n", G_MAXINT);
-                    arg_files = arg_analyse (argv, arg_opts);
-                    if (history != arg_h.val
-                                        && 0 <= arg_h.val && arg_h.val <= 10)
-                      {
-                        /* ja:履歴の整理 */
-                        GList *glist;
-                        GtkWidget *menu_shell;
-
-                        history = arg_h.val;
-                        menu_shell = gtk_item_factory_get_widget
-                                                (ifactory_menu, "<main>/File");
-                        glist = gtk_container_children
-                                                (GTK_CONTAINER (menu_shell));
-                        for (i = g_list_length (glist) - 3;
-                            i > history - (history == 0) + MENUFILE - 2; i--)
-                          gtk_container_remove (GTK_CONTAINER
-                                    (menu_shell), g_list_nth_data (glist, i));
-                        g_list_free (glist);
-                      }
-                    newfile = arg_n.flag;
-                    def_width = array[0];
-                    def_height = array[1];
-                    second = arg_x.flag;
-                    for (i = 1; argv[i]; i++)
-                        if (arg_files[i])
-                          {
-                            tmaid = file_open_edit (argv[i]);
-                            if (arg_l.val != 0) /* 指定行に移動 */
-                              jump_operation (tmaid, arg_l.val);
-                          }
-                    g_free (arg_files);
-                    g_strfreev (argv);
-                    DdeUnaccessData (hData);
-                  }
-                DdeFreeDataHandle (hData);
-                hConv = DdeConnect (ddeInst, hszService, hszTopic2, NULL);
-                if (hConv != NULL)
-                    DdeDisconnect (hConv);
-              }
-      }
-    return NULL;
-}
-#endif
-
-
 static gchar *
 menu_translate (const gchar *path,
                 gpointer     func_data)
@@ -232,11 +94,12 @@ menu_translate (const gchar *path,
 int main(int argc,char *argv[])
 {
     gboolean *arg_files, license = FALSE;
-    gchar *arg, *section, *key, *tmp, *utf8str;
+    gchar *section, *key, *tmp, *utf8str;
     const gchar *charset;
-    gint i, count=0, leng, length=0, init_line = 0;
+    gint i, count=0, init_line = 0;
     Profile *profile;
     TmaidWindow *tmaid;
+    GObject *accel;
     GdkBitmap *mask;
     GdkPixmap *pixmap;
     GtkAccelGroup *accel_group;
@@ -279,7 +142,7 @@ int main(int argc,char *argv[])
 {N_("/Search/_Previous"),            "<shift>F3",  command_next,    1,"<Item>"},
 {N_("/Search/_Replace..."),          "<control>H", command_replace, 0,"<Item>"},
 {N_("/_Option"),                     NULL,         NULL,            0,"<Branch>"},
-{N_("/Option/_Configuration..."),    NULL,         conf_dialog,     0,"<Item>"},
+{N_("/Option/_Configuration..."),    NULL,         command_conf,    0,"<Item>"},
 {N_("/Option/File _Type..."),        NULL,         format_dialog,   0,"<Item>"},
 {N_("/_Window"),                     NULL,         NULL,            0,"<Branch>"},
 {N_("/_Help"),                       NULL,         NULL,            0,"<Branch>"},
@@ -701,23 +564,15 @@ TMAID_COPYRIGHT_NOTICE"\n"
                                                 drag_types,1,GDK_ACTION_COPY);
     g_signal_connect (G_OBJECT (window), "drag-data-received",
                                 G_CALLBACK (signal_drag_data_received), NULL);
-    /* クリップボード/プロセス間通信 */
+    /* クリップボード */
     atom_targets=gdk_atom_intern("TARGETS",FALSE);
     atom_compound=gdk_atom_intern("COMPOUND_TEXT",FALSE);
     atom_text=gdk_atom_intern("TEXT",FALSE);
     atom_utf8 = gdk_atom_intern ("UTF8_STRING", FALSE);
-    atom_textmaid0=gdk_atom_intern("Text maid InterProcess communication 0",
-                                                                        FALSE);
-    atom_textmaid1=gdk_atom_intern("Text maid InterProcess communication 1",
-                                                                        FALSE);
     gtk_selection_add_targets (window, GDK_SELECTION_PRIMARY,
                         targets, sizeof (targets) / sizeof (GtkTargetEntry));
     gtk_selection_add_targets (window, GDK_SELECTION_CLIPBOARD,
                         targets, sizeof (targets) / sizeof (GtkTargetEntry));
-    if (!second) {
-        gtk_selection_add_targets(window,atom_textmaid0,targets,1);
-        gtk_selection_add_targets(window,atom_textmaid1,targets,1);
-    }
     g_signal_connect (G_OBJECT (window), "selection-clear-event",
                                     G_CALLBACK (signal_selection_clear), NULL);
     g_signal_connect (G_OBJECT (window), "selection-get",
@@ -750,8 +605,11 @@ TMAID_COPYRIGHT_NOTICE"\n"
     gtk_item_factory_create_items (ifactory_menu,
                         sizeof (menu_items) / sizeof (GtkItemFactoryEntry),
                                                             menu_items, NULL);
-    gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
     menu_bar = gtk_item_factory_get_widget (ifactory_menu, "<main>");
+    /* ja:アクセルグループ */
+    accel = misc_accel_new ();
+    misc_accel_set_window (MISC_ACCEL (accel), GTK_WINDOW (window));
+    misc_accel_add_accel_group (MISC_ACCEL (accel), accel_group);
     /* ツールバー */
     toolbar = gtk_toolbar_new ();
     gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar),
@@ -824,124 +682,19 @@ TMAID_COPYRIGHT_NOTICE"\n"
     /* メニュー表示 */
     set_menu_bar(NULL);
 
-    /* 既に起動しているかチェックする */
-    if (!second) {
-#ifdef G_OS_WIN32
-        HCONV hConv;
-#endif /* G_OS_WIN32 */
+  /* ja:既に起動しているかチェックする */
+  if (!second)
+    {
+      GObject *comm;
 
-        if (argc > 1)
-            for (i = 0; i < argc; i++)
-              {
-                if (arg_files[i])
-                  {
-                    arg = fileio_get_full_path (argv[i]);
-                    leng = g_strlen (arg) * sizeof (gchar);
-                    arg_text = g_realloc (arg_text,
-                                            length + leng + sizeof (gchar));
-                    g_memmove (arg_text + length, arg, leng);
-                    g_free (arg);
-                  }
-                else
-                  {
-                    leng = g_strlen (argv[i]) * sizeof (gchar);
-                    arg_text = g_realloc (arg_text,
-                                            length + leng + sizeof (gchar));
-                    g_memmove (arg_text + length, argv[i], leng);
-                  }
-                length += leng;
-                arg_text[length++] = '\n';
-              }
-        if (length > 0)
-            arg_text[length - 1] = '\0';
-#ifdef G_OS_WIN32
-        if (DdeInitialize (&ddeInst, DdemlCallback,
-                            APPCLASS_STANDARD | CBF_FAIL_SELFCONNECTIONS, 0)
-                                                            != DMLERR_NO_ERROR)
-          {
-            g_free (arg_files);
-            gtk_exit (0);
-          }
-        hszService = DdeCreateStringHandle (ddeInst,
-                                    _T("Text maid InterProcess communication"),
-# ifdef UNICODE
-                                                                CP_WINANSI);
-# else /* not UNICODE */
-                                                                CP_WINUNICODE);
-# endif
-        hszTopic0 = DdeCreateStringHandle (ddeInst,
-                                _T("Text maid InterProcess communication 0"),
-# ifdef UNICODE
-                                                                CP_WINANSI);
-# else /* not UNICODE */
-                                                                CP_WINUNICODE);
-# endif
-        hszTopic1 = DdeCreateStringHandle (ddeInst,
-                                _T("Text maid InterProcess communication 1"),
-# ifdef UNICODE
-                                                                CP_WINANSI);
-# else /* not UNICODE */
-                                                                CP_WINUNICODE);
-# endif
-        hszTopic2 = DdeCreateStringHandle (ddeInst,
-                                _T("Text maid InterProcess communication 2"),
-# ifdef UNICODE
-                                                                CP_WINANSI);
-# else /* not UNICODE */
-                                                                CP_WINUNICODE);
-# endif
-        if (hszService == NULL
-                || hszTopic0 == NULL || hszTopic1 == NULL || hszTopic2 == NULL)
-          {
-            if (hszService != NULL)
-                DdeFreeStringHandle (ddeInst, hszService);
-            if (hszTopic0 != NULL)
-                DdeFreeStringHandle (ddeInst, hszTopic0);
-            if (hszTopic1 != NULL)
-                DdeFreeStringHandle (ddeInst, hszTopic1);
-            if (hszTopic2 != NULL)
-                DdeFreeStringHandle (ddeInst, hszTopic2);
-            DdeUninitialize (ddeInst);
-            g_free (arg_files);
-            gtk_exit (0);
-          }
-        DdeNameService (ddeInst, hszService, NULL, DNS_REGISTER);
-        hConv = DdeConnect (ddeInst, hszService, hszTopic0, NULL);
-        if (hConv != 0)
-          {
-            /* 既に起動しているとき */
-            DdeDisconnect (hConv);
-            while (arg_text != NULL)
-                while (gtk_events_pending ())
-                    gtk_main_iteration ();
-            DdeNameService (ddeInst, hszService, NULL, DNS_UNREGISTER);
-            DdeFreeStringHandle (ddeInst, hszService);
-            DdeFreeStringHandle (ddeInst, hszTopic0);
-            DdeFreeStringHandle (ddeInst, hszTopic1);
-            DdeFreeStringHandle (ddeInst, hszTopic2);
-            DdeUninitialize (ddeInst);
-            g_free (arg_files);
-            gtk_exit (0);
-          }
-#else /* not G_OS_WIN32 */
-        if (length > 0)
-            gtk_selection_owner_set (window, atom_textmaid1, GDK_CURRENT_TIME);
-        gtk_selection_convert(window,atom_textmaid0,
-                                GDK_SELECTION_TYPE_STRING,GDK_CURRENT_TIME);
-        while (instance<0)
-            while (gtk_events_pending())
-                gtk_main_iteration();
-        if (instance>0) {
-            /* 既に起動しているとき */
-            while (arg_text!=NULL)
-                while (gtk_events_pending())
-                    gtk_main_iteration();
-            g_free(arg_files);
-            gtk_exit(0);
+      comm = misc_comm_new (window, "Text maid InterProcess communication");
+      if (!misc_comm_is_first (MISC_COMM (comm)))
+        {
+          misc_comm_send_with_files (MISC_COMM (comm), argc, argv, arg_files);
+          gtk_exit (0);
         }
-        gtk_selection_owner_set(window,atom_textmaid0,GDK_CURRENT_TIME);
-#endif /* not G_OS_WIN32 */
-        g_free(arg_text);
+      g_signal_connect (G_OBJECT (comm), "recv",
+                                    G_CALLBACK (signal_selection_recv), NULL);
     }
 
     /* 表示 */
@@ -1238,17 +991,7 @@ TMAID_COPYRIGHT_NOTICE"\n"
 #ifdef G_OS_UNIX
     g_free(printer.printer);
 #endif /* G_OS_UNIX */
-#ifdef G_OS_WIN32
-    if (ddeInst != 0)
-      {
-        DdeNameService (ddeInst, hszService, NULL, DNS_UNREGISTER);
-        DdeFreeStringHandle (ddeInst, hszService);
-        DdeFreeStringHandle (ddeInst, hszTopic0);
-        DdeFreeStringHandle (ddeInst, hszTopic1);
-        DdeFreeStringHandle (ddeInst, hszTopic2);
-        DdeUninitialize (ddeInst);
-      }
-#else /* not G_OS_WIN32 */
+#ifndef G_OS_WIN32
     g_free(printer.file);
 #endif /* not G_OS_WIN32 */
     for (i=0;i<find_num;i++)
