@@ -115,11 +115,9 @@ extern gchar *history_files[10];        /* ファイルの履歴 */
 extern gchar *open_path;                /* 開くのパス */
 extern gchar *save_path;                /* 名前を付けて保存のパス */
 extern gchar *clipboard_text;           /* クリップボードのテキスト */
-extern gchar *arg_text;                 /* プロセス間通信用変数 */
 extern gint def_width,def_height;       /* デフォルトのウインドウのサイズ */
 extern gint ftnum;                      /* ファイルタイプの数 */
 extern gint history;                    /* ファイルの履歴 */
-extern gint instance;                   /* プロセス間通信用変数 */
 extern gint tcount;                     /* ファイルタイプのカウンタ */
 extern guint timer_id;                  /* タイマID */
 extern FileType *ftype;                 /* ファイルタイプ */
@@ -127,8 +125,6 @@ extern GdkAtom atom_targets;            /* ターゲット */
 extern GdkAtom atom_text;               /* テキスト */
 extern GdkAtom atom_compound;           /* コンパウンド */
 extern GdkAtom atom_utf8;               /* UTF-8 */
-extern GdkAtom atom_textmaid0;          /* プロセス間通信用アトム */
-extern GdkAtom atom_textmaid1;          /* プロセス間通信用アトム */
 extern GtkWidget *window;               /* ウインドウ */
 extern GtkWidget *notebook;             /* ノートブック */
 extern GtkWidget *status;               /* ステータスウインドウ */
